#!/usr/bin/env python
import geopandas as gpd
import pandas as pd
import timeit
import sys
from mpi4py import MPI
from nes import *
import datetime

# Hide warning
pd.options.mode.chained_assignment = None

comm = MPI.COMM_WORLD
rank = comm.Get_rank()
size = comm.Get_size()

# Path to mask
shapefile_path = '/gpfs/projects/bsc32/models/NES_tutorial_data/timezones_2021c/timezones_2021c.shp'

# Original path: /esarchive/exp/monarch/a4dd/original_files/000/2022111512/MONARCH_d01_2022111512.nc
# Rotated grid from MONARCH
original_path = '/gpfs/projects/bsc32/models/NES_tutorial_data/MONARCH_d01_2022111512.nc'
nessy = open_netcdf(original_path)
nessy.keep_vars('O3')
nessy.load()

# Method can be centroid, nearest and intersection
nessy.spatial_join(shapefile_path, method='centroid')

print('SPATIAL JOIN - Rank: {0}. Shapefile: {1}'.format(rank, nessy.shapefile))

comm.Barrier()
sys.stdout.flush()

# Define projection
projection = 'regular'
lat_orig = 41.1
lon_orig = 1.8
inc_lat = 0.2
inc_lon = 0.2
n_lat = 10
n_lon = 10

# Method can be centroid, nearest and intersection
nessy = from_shapefile(shapefile_path, method='centroid', projection=projection, 
                       lat_orig=lat_orig, lon_orig=lon_orig, 
                       inc_lat=inc_lat, inc_lon=inc_lon, 
                       n_lat=n_lat, n_lon=n_lon)

print('FROM SHAPEFILE - Rank: {0}. Shapefile: {1}'.format(rank, nessy.shapefile))

comm.Barrier()
sys.stdout.flush()
